# Editor component Punctual/Area Lights Workflow Tests
Testing in this area should focus on the Punctual/Area Lights components.

## **General Docs**
* [O3DE Learn: Light Component](https://www.o3de.org/docs/user-guide/components/reference/atom/light/)

## Common Issues to Watch For
 - Crashes, soft-locks, hangs when launching Editor.exe or adding a component.
 - When a component settings value is changed, it has a visual impact on the level. 
   - The change can be subtle, but if no change is present log an issue


## Workflows
- Create various entities with meshes and materials and place them in the space. 
  - Explore each light type and place them against/around these points. 
    - Utilize various shapes and sizes 
    - disk/Spherical/Capsule are all good lights to create and mix.

## Prepare the level
Prepare a simple level for all workflows to be run against
- Launch the editor, and create a new level with default settings 
- Disable or delete the Sun entity 

### Suggested Time Box: 
15 minutes per workflow per platform. Note that the workflow below is the basic steps, feel free to experiment with other settings during the remaining time.
- With extra time try adding one more extra entities with mesh components and a material (Examples: "bunny.fbx", and "suzanne.fbx") 
- Try to make several different configurations of lights against the same mesh and confirm they correctly shift and display to your expectations.



Explore "Point (sphere)" Light component 
-------------------------------------
Lights have a specific location and radiate light equally in all directions, this version has a sphere shaped emitter. The attenuation value determines how fast the light drops off as you travel further from the light origin. Low attenuation values will spread the light further, while high attenuation values will keep it more compact.

| Workflow                                    | Requests                                                                                                                                                                                                                                                                       | Things to Watch For                                                                                                                                                                                                                                                                                                                                                                                                |
|---------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| 1. Add "Point (sphere)" Light               | <ul><li>Add a new entity to the level<li> add light component and set it's type to "Point (sphere)" <li> Move the light entity near the shaderball model so it casts light on the shaderball                                                                                   | <ul><li> Point sphere light component can be added. The sphere Shape is included.<li>Example ![pointLight](https://user-images.githubusercontent.com/41299597/215604813-bdfdc461-92e5-4d5b-962c-f8e674d18a25.png)                                                                                                                                                                                                                                                                                                                      |
| 2. Change color values and intensity modes  | <ul><li> Change the color value, observe change in light <li>Switch between intensity modes, adjust change intensity slider for each, observe change in light                                                                                                                  | <ul><li> Color in light picker chosen applies visually in the viewport. <li> When Intensity Mode is changed, the Intensity slider updates to reflect the output. <li> slider can then be used to change the Intensity according to the new mode. <ls> Visual changes in viewport should dim or brighten the light. ![ColorIntencity](https://user-images.githubusercontent.com/41299597/215605004-dfd2d2d2-798e-4c94-89c5-3fc2339ea8f1.png)                                                                                                |
| 3. Adjust Radius                            | <ul><li> Change Attenuation radius mode to Explicit <li> Set radius values from 1-10, observe change in light <li> Change Attenuation radius mode back to automatic                                                                                                            | <ul><li> Changing the radius value is reflected in the level by the sphere shape changing size. 1 would be small while 10 being larger. <li> The light radius does not reach out of the bounds of the sphere shape. <li> Example  ![radiusadjustment](https://user-images.githubusercontent.com/41299597/215605156-93a9de9e-cc63-4fbe-a1af-9f60c88c0f8b.png)|
| 4. Adjust and observe shadows               | <ul><li> Zoom into the shadow edge and enable Shadows <li> Switch between Shadowmap sizes, observe change in  shadow edge <li> Toggle between each of the shadow filtering methods (PCF, ESM, and ESM+PCF)<ul><li>change the values of Filtering Sample Count and ESM exponent | <ul><li> Shadow Map Sizes, the larger the number the smoother the edges of the shadows will appear. <li>Shadow Filtering Set the shadow filtering method to reduce aliasing in the shadowmap. percentage-closer filtering (PCF) and exponential shadow maps (ESM). ESM+PCF uses ESM, but falls back to PCF in areas where ESM might fail. <ul><li> Both modes will make the shadow edges appear more blured/smooth ![shadows](https://user-images.githubusercontent.com/41299597/215610414-ac6390a3-f54f-4724-985f-d7b2c8903469.png) |
| 5. Adjust settings on sphere shape          | <ul><li> Navigate to Sphere Shape component <li> Toggle on the Visible, Game View, and Filled settings <li> Increase the radius to a high value, observe change in light                                                                                                       | <ul><li> When Game View is activated the other active settings are visible when entering game mode. <li> Changing radius changes the size of the sphere shape which does not effect the light radius.                                                                                                                                                                                                              |

---

Explore "Point (simple punctual)" Light component 
-------------------------------------
Lights have a specific location and radiate light equally in all directions, this version has a no shape and is just a point in space. The attenuation value determines how fast the light drops off as you travel further from the light origin. Low attenuation values will spread the light further, while high attenuation values will keep it more compact.

| Workflow                                   | Requests                                                                                                                                                                                              | Things to Watch For                                                                                                                                                                                                                                                                                                 |
|--------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| 1. Add "Point (simple punctual)"         | <ul><li>Add a new entity to the level<li> add light component and set it's type to "Point (simple punctual)" <li> Move the light entity near the shaderball model so it casts light on the shaderball | <ul><li> Point sphere light component can be added.                                                                                                                                                                                                                                                                 |
| 2. Change color values and intensity modes | <ul><li> Change the color value, observe change in light <li>Switch between intensity modes, adjust change intensity slider for each, observe change in light                                         | <ul><li> Color in light picker chosen applies visually in the viewport. <li> When Intensity Mode is changed, the Intensity slider updates to reflect the output. <li> slider can then be used to change the Intensity according to the new mode. <ls> Visual changes in viewport should dim or brighten the light.  |
| 3. Adjust Radius                           | <ul><li> Change Attenuation radius mode to Explicit <li> Set radius values from 1-10, observe change in light <li> Change Attenuation radius mode back to automatic                                   | <ul><li> Changing the radius value is reflected in the level by the sphere shape changing size. 1 would be small while 10 being larger. <li> The light radius does not reach out of the bounds of the sphere shape.                                                                                                 |
---


Explore "Spot (disc)" Light component 
-------------------------------------
A light object that had both a location and direction. When enabled, it directs a cone of light in the specified direction. Light supports attenuation properties as well as shutters that harden or soften the edge of the projected spotlight. This version has a disc shape.

| Workflow                                   | Requests                                                                                                                                                                                                                                                                       | Things to Watch For                                                                                                                                                                                                                                                                                                                                                                                        |
|--------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| 1. Add "Spot (disc)" Light                 | <ul><li>Add a new entity to the level<li> add light component and set it's type to "Spot (disc)" <li> Move the light entity near the shaderball, and rotate the entity so the spotlight appears on the shaderball and ground plane                                             | <ul><li> Point sphere light component can be added. The Disk Shape is included.<li>Example  ![SpotDisk](https://user-images.githubusercontent.com/41299597/215605993-33dd1bce-fe68-4903-9bed-89ebd8f02f14.png)                                                                                                                                                                                                                                                                                                             |
| 2. Change color values and intensity modes | <ul><li> Change the color value, observe change in light <li>Switch between intensity modes, adjust change intensity slider for each, observe change in light                                         | <ul><li> Color in light picker chosen applies visually in the viewport. <li> When Intensity Mode is changed, the Intensity slider updates to reflect the output. <li> slider can then be used to change the Intensity according to the new mode. <ls> Visual changes in viewport should dim or brighten the light.                                                                                         |
| 3. Adjust Radius                           | <ul><li> Change Attenuation radius mode to Explicit <li> Set radius values from 1-10, observe change in light <li> Change Attenuation radius mode back to automatic                                                                                                            | <ul><li> Changing the radius value is reflected in the level by the sphere shape changing size. 1 would be small while 10 being larger. <li> The light radius does not reach out of the bounds of the sphere shape.                                                                                                                                                                                        |
| 4. Enable shutters                         | <ul><li> Toggle Enable shutters off, and observe change in light <li> Toggle Enable shutters again, adjust Inner angle and Outer angle, observe change in light                                                                                                                | <ul><li> Enabeling Shutters gives the user access to Inner and Outer Angle to adjust how wide or pointed the spot light is.                                                                                                                                                                                                                                                                                |
| 5. Adjust and observe shadows              | <ul><li> Zoom into the shadow edge and enable Shadows <li> Switch between Shadowmap sizes, observe change in  shadow edge <li> Toggle between each of the shadow filtering methods (PCF, ESM, and ESM+PCF)<ul><li>change the values of Filtering Sample Count and ESM exponent | <ul><li> Shadow Map Sizes, the larger the number the smoother the edges of the shadows will appear. <li>Shadow Filtering Set the shadow filtering method to reduce aliasing in the shadowmap. percentage-closer filtering (PCF) and exponential shadow maps (ESM). ESM+PCF uses ESM, but falls back to PCF in areas where ESM might fail. <ul><li> Both modes will make the shadow edges appear more blured/smooth |
| 6. Adjust settings on Disk shape           | <ul><li> Navigate to Disk Shape component <li> Toggle on the Visible, Game View, and Filled settings <li> Increase the radius to a high value, observe change in light                                                                                                         | <ul><li> When Game View is activated the other active settings are visible when entering game mode. <li> Changing radius changes the size of the disk shape which does not effect the light radius.                                                                                                                                                                                                        |
---

Explore "Spot (simple punctual)" Light component 
-------------------------------------
A light object that had both a location and direction. When enabled, it directs a cone of light in the specified direction. Light supports attenuation properties as well as shutters that harden or soften the edge of the projected spotlight.  This version has a no shape and is just a point in space.

| Workflow                                   | Requests                                                                                                                                                                                                                                       | Things to Watch For                                                                                                                                                                                                                                                                                                |
|--------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| 1. Add "Spot (simple punctual)"            | <ul><li>Add a new entity to the level<li> add light component and set it's type to "Spot (simple punctual)"  <li> Move the light entity near the shaderball, and rotate the entity so the spotlight appears on the shaderball and ground plane | <ul><li> Point sphere light component can be added.                                                                                                                                                                                                                                                                |
| 2. Change color values and intensity modes | <ul><li> Change the color value, observe change in light <li>Switch between intensity modes, adjust change intensity slider for each, observe change in light                                                                                  | <ul><li> Color in light picker chosen applies visually in the viewport. <li> When Intensity Mode is changed, the Intensity slider updates to reflect the output. <li> slider can then be used to change the Intensity according to the new mode. <ls> Visual changes in viewport should dim or brighten the light. |
| 3. Adjust Radius                           | <ul><li> Change Attenuation radius mode to Explicit <li> Set radius values from 1-10, observe change in light <li> Change Attenuation radius mode back to automatic                                                                            | <ul><li> Changing the radius value is reflected in the level by the sphere shape changing size. 1 would be small while 10 being larger. <li> The light radius does not reach out of the bounds of the sphere shape.                                                                                                |
| 4. Change properties for shutters          | <ul><li> Under Shutters, adjust Inner angle and Outer angle, observe change in light                                                                                                                                                           | <ul><li> Enabeling Shutters gives the user access to Inner and Outer Angle to adjust how wide or pointed the spot light is.                                                                                                                                                                                        | 
---

Explore Capsule Light component 
-------------------------------------
Capsule shape that emits light in all directions from the surface of the geometry.  Supports Attenuation properties, and is one of the more expensive lights in terms of resource usage. 

| Workflow                                   | Requests                                                                                                                                                                                  | Things to Watch For                                                                                                                                                                                                   |
|--------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| 1. Add "Capsule"                           | <ul><li>Add a new entity to the level<li> add light component and set it's type to "Capsule" <li> Move the light entity near the shaderball model so it casts light on the shaderball     | <ul><li> Point sphere light component can be added. The Capsule Shape is included.<li>Example ![capsule](https://user-images.githubusercontent.com/41299597/215606154-dc1b89ad-c209-4827-bb3a-d04d80574b92.png)                                                                                                                                                                                                               |
| 2. Change color values and intensity modes | <ul><li> Change the color value, observe change in light <li>Switch between intensity modes, adjust change intensity slider for each, observe change in light                             | <ul><li> Color in light picker chosen applies visually in the viewport. <li> When Intensity Mode is changed, the Intensity slider updates to reflect the output. <li> slider can then be used to change the Intensity according to the new mode. <ls> Visual changes in viewport should dim or brighten the light.  |
| 3. Adjust Radius                           | <ul><li> Change Attenuation radius mode to Explicit <li> Set radius values from 1-10, observe change in light <li> Change Attenuation radius mode back to automatic                       | <ul><li> Changing the radius value is reflected in the level by the sphere shape changing size. 1 would be small while 10 being larger. <li> The light radius does not reach out of the bounds of the sphere shape.   |
| 4. Adjust settings on Capsule shape        | <ul><li> Navigate to Capsule Shape component <li> Toggle on the Visible, Game View, and Filled settings <li> Increase the radius to a high value, observe change in light                 | <ul><li> When Game View is activated the other active settings are visible when entering game mode. <li> Changing radius changes the size of the Capsule shape which does not effect the light radius.                 |
---

Explore Quad Light component 
-------------------------------------
The Quad light is a rectangular shape that emits light in all directions from the surface of the geometry.  Supports Attenuation properties, and is one of the more expensive lights in terms of resource usage. 

| Workflow                                   | Requests                                                                                                                                                                           | Things to Watch For                                                                                                                                                                                                                                                                                               |
|--------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| 1. Add "Quad"                              | <ul><li>Add a new entity to the level<li> add light component and set it's type to "Quad" <li> Move the light entity near the shaderball model so it casts light on the shaderball | <ul><li> Point sphere light component can be added. The Quad Shape is included.<li>Example  ![quad](https://user-images.githubusercontent.com/41299597/215606202-d67a11fc-6f10-4378-ab8f-14b8b5389533.png)                                                                                                                                                                                                           |
| 2. Change color values and intensity modes | <ul><li> Change the color value, observe change in light <li>Switch between intensity modes, adjust change intensity slider for each, observe change in light                      | <ul><li> Color in light picker chosen applies visually in the viewport. <li> When Intensity Mode is changed, the Intensity slider updates to reflect the output. <li> slider can then be used to change the Intensity according to the new mode. <ls> Visual changes in viewport should dim or brighten the light. |
| 3. Adjust Radius                           | <ul><li> Change Attenuation radius mode to Explicit <li> Set radius values from 1-10, observe change in light <li> Change Attenuation radius mode back to automatic                | <ul><li> Changing the radius value is reflected in the level by the sphere shape changing size. 1 would be small while 10 being larger. <li> The light radius does not reach out of the bounds of the sphere shape.                                                                                               |
| 4. Toggle Directions options               | <ul><li>Toggle Both Directions option on and off, rotate light entity if needed, observe change in light                                                                           | <ul><li> Toggling the Both Directions on causes the light to come from both the front and back of the Polygon shape                                                                                                                                                                                               |
| 5. Toggle Fast Approximation option        | <ul><li>Toggle Fast Approximation option on and off, observe change in light                                                                                                       | <ul><li> Enable Fast Approximation uses a faster, lower-quality approximation for the lighting calculation, rather than the default high-quality linear transformed cosine technique.                                                                                                                             |
| 6. Adjust settings on Quad shape           | <ul><li> Navigate to Quad Shape component <li> Toggle on the Visible, Game View, and Filled settings <li> Increase the radius to a high value, observe change in light             | <ul><li> When Game View is activated the other active settings are visible when entering game mode. <li> Changing radius changes the size of the Quad shape which does not effect the light radius.                                                                                                               |
---


Explore Polygon light component 
-------------------------------------
Polygon light, is a polygon plane shape that can be adjusted. Emits light in all directions from the surface of the geometry.  Supports Attenuation properties, directional settings, and is the most expensive lights in terms of resource usage. 

| Workflow                                   | Requests                                                                                                                                                                                                                       | Things to Watch For                                                                                                                                                                                                                                                                                               |
|--------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| 1. Add "Polygon"                           | <ul><li>Add a new entity to the level<li> add light component and set it's type to "Polygon" <li> Move the light entity near the shaderball model so it casts light on the shaderball                                          | <ul><li> Point sphere light component can be added. The Polygon Shape is included.<li>Example  ![polygon](https://user-images.githubusercontent.com/41299597/215606269-9e9d4a85-e576-4fb1-a7d2-235b5af2820b.png)                                                                                                                                                                                                                |
| 2. Change color values and intensity modes | <ul><li> Change the color value, observe change in light <li>Switch between intensity modes, adjust change intensity slider for each, observe change in light                                                                  | <ul><li> Color in light picker chosen applies visually in the viewport. <li> When Intensity Mode is changed, the Intensity slider updates to reflect the output. <li> slider can then be used to change the Intensity according to the new mode. <ls> Visual changes in viewport should dim or brighten the light. |
| 3. Adjust Radius                           | <ul><li> Change Attenuation radius mode to Explicit <li> Set radius values from 1-10, observe change in light <li> Change Attenuation radius mode back to automatic                                                            | <ul><li> Changing the radius value is reflected in the level by the sphere shape changing size. 1 would be small while 10 being larger. <li> The light radius does not reach out of the bounds of the sphere shape.                                                                                               |
| 4. Toggle Directions options               | <ul><li>Toggle Both Directions option on and off, rotate light entity if needed, observe change in light                                                                                                                       | <ul><li> Toggling the Both Directions on causes the light to come from both the front and back of the Polygon shape                                                                                                                                                                                               |
| 5. Adjust settings on Polygon shape        | <ul><li> Navigate to Polygon Shape component <li> Toggle on the Visible, Game View, and Filled settings <li> Increase the radius to a high value, observe change in light                                                      | <ul><li> When Game View is activated the other active settings are visible when entering game mode. <li> Changing radius changes the size of the Polygon shape which does not effect the light radius.                                                                                                            |
---
